@@ -1,19 +1,20 @@
+pub mod consts;
 pub mod types;
 pub mod utils;
 use serde_json::json;
 use serde_json::to_string;
 pub use types::*;
 
-pub async fn new(playit_opts: Option<PlayItOpts>) -> Result<PlayIt, String> {
-  return PlayIt::new(playit_opts).await;
+pub fn new(playit_opts: Option<PlayItOpts>) -> Result<PlayIt, String> {
+  return PlayIt::new(playit_opts);
 }
 
 impl PlayIt {
-  pub async fn new(playit_opts: Option<PlayItOpts>) -> Result<Self, String> {
-    return utils::get_defaults(playit_opts).await;
+  pub fn new(playit_opts: Option<PlayItOpts>) -> Result<Self, String> {
+    return utils::get_defaults(playit_opts);
   }
 
-  pub async fn create_tunnel(&self, mut options: CreateTunnelOptions) -> Tunnel {
+  pub fn create_tunnel(&self, mut options: CreateTunnelOptions) -> Tunnel {
     options.ip = Option::from(options.ip.unwrap_or(String::from("127.0.0.1")));
 
     let tunnel_id = self
@@ -30,10 +31,8 @@ impl PlayIt {
                         .req_client
                         .get(self.api_path.join("/account/agents").unwrap())
                         .send()
-                        .await
                         .unwrap()
                         .json::<Agents>()
-                        .await
                         .unwrap()
                         .agents
                         .into_iter()
@@ -45,10 +44,8 @@ impl PlayIt {
         .unwrap(),
       )
       .send()
-      .await
       .unwrap()
       .json::<Id>()
-      .await
       .unwrap()
       .id;
 
@@ -57,24 +54,22 @@ impl PlayIt {
         .req_client
         .get(self.api_path.join("/account/tunnels").unwrap())
         .send()
-        .await
         .unwrap()
         .json::<Tunnels>()
-        .await
         .unwrap()
         .tunnels
         .into_iter()
         .find(|tunnel| tunnel.id == tunnel_id)
         .unwrap();
 
-      if !data.domain_id.is_none() && !data.connect_address.is_none() {
+      if data.domain_id.is_some() && data.connect_address.is_some() {
         break data;
       }
     };
   }
 
   #[cfg(feature = "enable-tunnels")]
-  pub async fn enable_tunnel(&self, id: i32) {
+  pub fn enable_tunnel(&self, id: i32) {
     self
       .req_client
       .get(
@@ -84,12 +79,11 @@ impl PlayIt {
           .unwrap(),
       )
       .send()
-      .await
       .expect(&format!("Failed To Enable The Tunnel"));
   }
 
   #[cfg(feature = "disable-tunnels")]
-  pub async fn disable_tunnel(&self, id: i32) {
+  pub fn disable_tunnel(&self, id: i32) {
     self
       .req_client
       .get(
@@ -99,7 +93,6 @@ impl PlayIt {
           .unwrap(),
       )
       .send()
-      .await
       .expect(&format!("Failed To Failed The Tunnel"));
   }
 
